@@ -2,9 +2,10 @@
 # housekeeping
 ########################################################################
 
-package Exporter::Proxy v1.8.1;
+package Exporter::Proxy;
 
-use v5.20;
+use v5.12;
+use strict;
 
 use Carp;
 
@@ -15,6 +16,9 @@ use Symbol      qw( qualify_to_ref  );
 # package variables
 ########################################################################
 
+our $VERSION    = '1.4';
+$VERSION = eval $VERSION;
+
 my $disp_list   = 'DISPATCH_OK';
 
 ########################################################################
@@ -49,10 +53,8 @@ sub import
 
     # maybe carp about extraneous arguments here?
 
-    my $disp        = delete $argz{ dispatch    } || '';
-    my $preproc     = delete $argz{ prefilter   } || '';
-    my $postproc    = delete $argz{ postfilter  } || '';
-    my $inst_import = delete $argz{ import      } // 1;
+    my $disp    = delete $argz{ dispatch    } || '';
+    my $preproc = delete $argz{ prefilter   } || '';
 
     # if a dispatcher is being used then it must
     # be exported. in most cases this will be the
@@ -110,12 +112,32 @@ sub import
         }
     }
 
+    my $pre_handler
+    = do
+    {
+        if( $preproc )
+        {
+            sub
+            {
+                my $handler = $source->can( $preproc )
+                or die "$source cannot '$preproc'\n";
+
+                &$handler
+            }
+        }
+        else
+        {
+            state $stub = sub{}
+        }
+    };
+
     @exportz
     or carp "Oddity: nothing requested for export!";
 
     my $exports = qualify_to_ref 'exports', $source;
+    my $import  = qualify_to_ref 'import',  $source;
 
-    undef &$exports;
+    undef &{ *$_ } for ( $exports, $import );
 
     *$exports
     = sub
@@ -128,98 +150,58 @@ sub import
         : [ @exportz ]
     };
 
-    $inst_import
-    and
-    do
+    *$import
+    = sub
     {
-        my $import  = qualify_to_ref 'import',  $source;
+        # discard the package as first argument:
+        # $pkg->import
 
-        undef &$import;
+        shift;
 
-        my $find_pre    
-        = $preproc
-        ?   sub 
-            {
-                $source->can( $preproc )
-                or die "Unusable $source: cannot '$preproc'";
-            }
-        : $stub
-        ;
+        my $caller  = caller;
+        
+        # allow the caller to pre-process the arguments.
+        # notice this happens *before* ":noexport" is 
+        # processed.
 
-        my $find_post    
-        = $postproc
-        ?   sub 
-            {
-                $source->can( $postproc )
-                or die "Unusable $source: cannot '$postproc'";
-            }
-        : $stub
-        ;
+        &$pre_handler;
 
-        *$import
-        = sub
+        # empty list => use @exportz.
+        # :noexport  => use empty list.
+
+        if( first { ':noexport' eq $_ } @_ )
         {
-            # these are delayed since the "use E::P" is 
-            # usually dealt with before the subs are defined
-            # in the caller.
+            @_  = ();
+        }
+        elsif( @_ )
+        {
+            # nothing more for the moment.
+        }
+        else
+        {
+            @_  = @exportz;
+        }
 
-            state $pre_handler  = $find_pre->();
-            state $post_handler = $find_post->();
+        # resolve these at runtime to account for
+        # possible autoloading, etc.
 
-            # discard the package as first argument:
-            # $pkg->import
+        for my $arg ( @_ )
+        {
+            index $arg, ':'
+            or next;
 
-            shift;
-
-            my $caller  = caller;
-            
-            # allow the caller to pre-process the arguments.
-            # notice this happens *before* ":noexport" is 
-            # processed.
-
-            &$pre_handler
-            if $pre_handler;
-
-            # empty list => use @exportz.
-            # :noexport  => use empty list.
-
-            if( first { ':noexport' eq $_ } @_ )
+            if( first { $arg eq $_ }  @exportz )
             {
-                @_  = ();
-            }
-            elsif( @_ )
-            {
-                # nothing more for the moment.
+                my $source  = qualify_to_ref $arg, $source;
+                my $install = qualify_to_ref $arg, $caller;
+
+                *$install   = *$source;
             }
             else
             {
-                @_  = @exportz;
+                die "Bogus $source: '$arg' not exported";
             }
-
-            # resolve these at runtime to account for
-            # possible autoloading, etc.
-
-            for my $arg ( @_ )
-            {
-                index $arg, ':'
-                or next;
-
-                if( first { $arg eq $_ }  @exportz )
-                {
-                    my $source  = qualify_to_ref $arg, $source;
-                    my $install = qualify_to_ref $arg, $caller;
-
-                    *$install   = *$source;
-                }
-                else
-                {
-                    die "Bogus $source: '$arg' not exported";
-                }
-            }
-
-            goto &$post_handler
-            if $post_handler;
-        };
+        }
     };
 
     return
@@ -255,6 +237,7 @@ Exporter::Proxy - Simplified symbol export & proxy dispatch.
 
     my $exported    = $object->exports;
 
+
     package Some::Other;
 
     use My::Module qw( foo );   # only exports foo
@@ -267,7 +250,7 @@ Exporter::Proxy - Simplified symbol export & proxy dispatch.
     # subroutine, Bar as an array, or foo may 
     # be overloaded with &foo, %foo, @foo, $foo.
 
-    $value eq $Bar[0]
+    $value ~~ $Bar[0]
     or croak "Invalid '$value'";
 
     delete $foo{ somekey }
@@ -275,8 +258,9 @@ Exporter::Proxy - Simplified symbol export & proxy dispatch.
 
     my $bletch  = $foo || 'oops, no $foo';
 
-    # if the caller does not want to import
-    # anything from the module by default:
+    # if the caller does not want to export
+    # anything from the module when it is used,
+    # ":noexport" does just that.
 
     use My::Module qw( :noexport );
 
@@ -315,21 +299,6 @@ Exporter::Proxy - Simplified symbol export & proxy dispatch.
     # modifying $test_ref does not affect
     # the exported items.
 
-    # some modules may want to use their own import, pulling
-    # in only exports and the dispatcher.
-
-    package Foo::Bar;
-
-    use Exporter::Proxy qw( import=0 );
-
-    sub import
-    {
-        # left as-is, package has to implement its own
-        # export utility for @exports.
-
-        ...
-    }
-
 =head1 DESCRIPTION
 
 This installs 'import' and 'exports' subroutines 
@@ -376,8 +345,8 @@ With no arguments the import uses the original
 exports list, pushing all of the symbols into
 the caller's space.
 
-The optional argument ':noexport' avoids exporting
-any symbols to the caller's space.
+The optional argument ':noexport' short-circuts
+export of any symbols to the caller's space.
 
 Other than ':noexport' any arguments with leading
 colons are silently ignored by import.
@@ -541,23 +510,6 @@ Aside: In later versions of perl
 
 makes it easier to get $i and the value.
 
-The postfilter is called as a final step in the import sub
-via goto &$post_handler. It cannot affect the stack used by 
-import but will have access to caller() for determining the
-calling class. THi can be usefuil for cases where some 
-information is managed by class such as default files or 
-per-package counts:
-
-    use Exporter::Proxy qw( postfilter=store_exports ... );
-
-    sub store_exports
-    {
-        # this returns the package calling import
-
-        my $caller  = caller;
-
-        $info{ $caller } = ...
-    }
 
 =back
 
@@ -687,22 +639,12 @@ and "prove t/00*.t" will give a quick, standard
 first pass as to whether they compile and are 
 minimally usable.
 
-=head1 SEE ALSO
-
-=over 4
-
-=item Symbol
-
-Used to export symbols w/o turning off strict.
-
-=back
-
 =head1 AUTHOR
 
 Steven Lembark <lembark@wrkhors.com>
 
 =head1 LICENSE
 
-Copyright (C) 2009-2016 Workhorse Computing.
-This code is released under the same terms as Perl 5.22,
+Copyright (C) 2009 Workhorse Computing.
+This code is released under the same terms as Perl 5.10.0,
 or any later version of Perl, itself.
